##################################################
##  Non-Participation in Democratic Assemblies: ##
##        Factors, Reasons, Suggestions         ##
##################################################

## November 2024, PR

## Packages:
library(foreign)
library(survey)
library(cregg)

## Data:
gl <- read.spss("C:/***/***/***/***/Glarus_Assemblies.sav",
                use.value.labels=F, to.data.frame=T, reencode="UTF-8")

#################################################################################################
## Table 2: Self-reported participation in communal assemblies five years prior to the survey: ##
##          descriptives of individual features                                                ##
#################################################################################################

wtd <- svydesign(ids=~1, data=gl, weights=~gew)

# Tertiary education
round(prop.table(svytable(~tertiary + partass, design=wtd), 2)*100, 1)
round(prop.table(svytable(~tertiary, design=wtd))*100, 1)
svychisq(~tertiary + partass, design=wtd, statistic="Chisq")

# Internal political efficacy
round(svyby(~efficacy_int, by=~partass, design=wtd, FUN=svymean, vartype="ci", na.rm=T), 1)
round(svymean(x=~efficacy_int, design=wtd, na.rm=T), 1)
svyranktest(efficacy_int ~ partass, design=wtd, test=c("KruskalWallis"))

# Children in household
round(prop.table(svytable(~children + partass, design=wtd), 2)*100, 1)
round(prop.table(svytable(~children, design=wtd))*100, 1)
svychisq(~children + partass, design=wtd, statistic="Chisq")

# Interested in local politics
round(prop.table(svytable(~interest + partass, design=wtd), 2)*100, 1)
round(prop.table(svytable(~interest, design=wtd))*100, 1)
svychisq(~interest + partass, design=wtd, statistic="Chisq")

# Attachment to municipality
round(svyby(~attachment, by=~partass, design=wtd, FUN=svymean, vartype="ci", na.rm=T), 1)
round(svymean(x=~attachment, design=wtd, na.rm=T), 1)
summary(aov(attachment ~ partass, data=gl, weights=gl$gew))

# Homeownership
round(prop.table(svytable(~homeownership + partass, design=wtd), 2)*100, 1)
round(prop.table(svytable(~homeownership, design=wtd))*100, 1)
svychisq(~homeownership + partass, design=wtd, statistic="Chisq")

# Years of residence
round(svyby(~relyearres, by=~partass, design=wtd, FUN=svymean, vartype="ci", na.rm=T), 2)
round(svymean(x=~relyearres, design=wtd, na.rm=T), 2)
summary(aov(relyearres ~ partass, data=gl, weights=gl$gew))

# Network membership score
round(svyby(~localnet, by=~partass, design=wtd, FUN=svymean, vartype="ci", na.rm=T), 1)
round(svymean(x=~localnet, design=wtd, na.rm=T), 1)
svyranktest(localnet ~ partass, design=wtd, test=c("KruskalWallis"))

# Uneasy feeling in public meetings
round(svyby(~meetav, by=~partass, design=wtd, FUN=svymean, vartype="ci", na.rm=T), 1)
round(svymean(x=~meetav, design=wtd, na.rm=T), 1)
svyranktest(meetav ~ partass, design=wtd, test=c("KruskalWallis"))

# Uneasiness about conflicts 
round(svyby(~conflav, by=~partass, design=wtd, FUN=svymean, vartype="ci", na.rm=T), 1)
round(svymean(x=~conflav, design=wtd, na.rm=T), 1)
svyranktest(conflav ~ partass, design=wtd, test=c("KruskalWallis"))

# External political efficacy
round(svyby(~efficacy_ext, by=~partass, design=wtd, FUN=svymean, vartype="ci", na.rm=T), 1)
round(svymean(x=~efficacy_ext, design=wtd, na.rm=T), 1)
svyranktest(efficacy_ext ~ partass, design=wtd, test=c("KruskalWallis"))

# Trust in local government 
round(svyby(~trust, by=~partass, design=wtd, FUN=svymean, vartype="ci", na.rm=T), 1)
round(svymean(x=~trust, design=wtd, na.rm=T), 1)
svyranktest(trust ~ partass, design=wtd, test=c("KruskalWallis"))

# Critical of assembly 
round(svyby(~biasrepr, by=~partass, design=wtd, FUN=svymean, vartype="ci", na.rm=T), 1)
round(svymean(x=~biasrepr, design=wtd, na.rm=T), 1)
svyranktest(biasrepr ~ partass, design=wtd, test=c("KruskalWallis"))

# Age
svyby(~age, by=~partass, design=wtd, svyquantile, quantiles=0.5, na.rm=TRUE)
svyquantile(x=~age, design=wtd, quantile=0.5, na.rm=T)
summary(aov(age ~ partass, data=gl, weights=gl$gew))

# Gender
round(prop.table(svytable(~gender + partass, design=wtd), 2)*100, 1)
prop.table(svytable(~gender, design=wtd))*100
svychisq(~gender + partass, design=wtd, statistic="Chisq")

# Total
round(prop.table(svytable(~partass, design=wtd))*100, 1)


#####################################################################################
##  Table 3: Predictors for self-reported participation in communal assemblies in  ##
##           the 5 years prior to interview (ordinal logistic regression)          ##
#####################################################################################

gl$partass <- as.factor(gl$partass)
wtd <- svydesign(ids = ~1, data = gl, weights = ~gew)

# Function
summary_table <- function(model){
  erg <- coef(summary(model))
  pval <- pnorm(abs(erg[, "t value"]),lower.tail = FALSE)* 2
  erg <- cbind(erg, "p.value" = round(pval,3))
  rm(pval)
  return(erg)
}

### M0: Controls
summary_table(svyolr(partass ~ age + gender, design = wtd))

### M1
summary_table(svyolr(partass ~ age + gender +
                       tertiary + efficacy_int + children + interest + attachment +
                       homeownership + relyearres + localnet, design = wtd))

### M2
summary_table(svyolr(partass ~ age + gender + meetav + conflav, design=wtd))

### M3
summary_table(svyolr(partass ~ age + gender + efficacy_ext + trust + biasrepr, design=wtd))

### M4: Full model
summary_table(svyolr(partass ~ age + gender + tertiary + efficacy_int + children +
                       interest + attachment + homeownership + relyearres + localnet +
                       meetav + conflav + efficacy_ext + trust + biasrepr, design=wtd))


################################################
## Table Appendix: Parallel Trends Assumption ##
################################################

# Dummy Never vs. Sometimes/Always:
gl$nevervsrest <- ifelse(gl$partass == 1, 0, 1)

# Dummy Never/Sometimes vs. Always
gl$alwaysvsrest <- ifelse(gl$partass == 3, 1, 0)

# SVY-Design 
wtd <- svydesign(ids = ~1, data = gl, weights = ~gew)

# Regression Never vs. Sometimes/Always:
summary(svyglm(nevervsrest ~ age + gender + tertiary + efficacy_int + children +
                 interest + attachment + homeownership + relyearres + localnet +
                 meetav + conflav + efficacy_ext + trust + biasrepr, design = wtd, family=quasibinomial))

# Regression Never/Sometimes vs. Always
summary(svyglm(alwaysvsrest ~ age + gender + tertiary + efficacy_int + children +
                 interest + attachment + homeownership + relyearres + localnet +
                 meetav + conflav + efficacy_ext + trust + biasrepr, design = wtd, family=quasibinomial))



###########################################################################################
## Table Appendix: Respondents' Self-reported Participation in Elections and Referendums ##
###########################################################################################

# 2018 local elections
round(prop.table(svytable(~partlocal + partass, design=wtd), 2)*100, 1)
round(prop.table(svytable(~partlocal, design=wtd))*100, 1)
svychisq(~partlocal + partass, design=wtd, statistic="Chisq")

# 2018 cantonal elections: Cantonal government
round(prop.table(svytable(~partcgov + partass, design=wtd), 2)*100, 1)
round(prop.table(svytable(~partcgov, design=wtd))*100, 1)
svychisq(~partcgov + partass, design=wtd, statistic="Chisq")

# 2018 cantonal elections: Cantonal parliament
round(prop.table(svytable(~partcparl + partass, design=wtd), 2)*100, 1)
round(prop.table(svytable(~partcparl, design=wtd))*100, 1)
svychisq(~partcparl + partass, design=wtd, statistic="Chisq")

# 2019 national elections: National parliament
round(prop.table(svytable(~partnparl + partass, design=wtd), 2)*100, 1)
round(prop.table(svytable(~partnparl, design=wtd))*100, 1)
svychisq(~partnparl + partass, design=wtd, statistic="Chisq")

# National referendums
round(svyby(~partref, by = as.numeric((wtd$variables$partass)), design=wtd, FUN=svymean, vartype="ci", na.rm=T), 1)
round(svymean(x=~partref, design=wtd, na.rm=T), 1)
svyranktest(partref ~ partass, design=wtd, test=c("KruskalWallis"))

# Total
round(svytable(~partass, design=wtd))


#########################################
## Conjoint-Analysis: Data Preparation ##
#########################################

gl.cj <- data.frame(ID = rep(gl$ID, 4),
                     gew = rep(gl$gew, 4),
                     task = rep(c(1,2), each=5420),
                     profile = rep(c(1,2), each=2710, times=2),
                     select = c(rep(gl$cj1select, 2), rep(gl$cj2select, 2)),
                     agenda =        factor(c(gl$cj11_agenda,        gl$cj12_agenda,        gl$cj21_agenda,        gl$cj22_agenda)),
                     duration =      factor(c(gl$cj11_duration,      gl$cj12_duration,      gl$cj21_duration,      gl$cj22_duration)),
                     scheduling =    factor(c(gl$cj11_scheduling,    gl$cj12_scheduling,    gl$cj21_scheduling,    gl$cj22_scheduling)),
                     journey =       factor(c(gl$cj11_journey,       gl$cj12_journey,       gl$cj21_journey,       gl$cj22_journey)),
                     amenities =     factor(c(gl$cj11_amenities,     gl$cj12_amenities,     gl$cj21_amenities,     gl$cj22_amenities)),
                     accompaniment = factor(c(gl$cj11_accompaniment, gl$cj12_accompaniment, gl$cj21_accompaniment, gl$cj22_accompaniment)),
                     atmosphere =    factor(c(gl$cj11_atmosphere,    gl$cj12_atmosphere,    gl$cj21_atmosphere,    gl$cj22_atmosphere)))

gl.cj$select[gl.cj$select==1 & gl.cj$profile==1] <- 1
gl.cj$select[gl.cj$select==2 & gl.cj$profile==1] <- 0
gl.cj$select[gl.cj$select==1 & gl.cj$profile==2] <- 0
gl.cj$select[gl.cj$select==2 & gl.cj$profile==2] <- 1

# Complete cases
d.cc <- gl.cj[complete.cases(gl.cj$select),] #N=9928


######################################################
## Conjoint Analysis:                               ## 
## Assumption 1: Stability and No Carryover Effects ##
######################################################

# Differences in Marginal Means by Task
d.cc$task <- as.factor(d.cc$task)
rob1 <- cj(data = d.cc, formula=select ~ agenda + duration + scheduling + journey 
           + amenities + accompaniment + atmosphere, id=~ID, weights=~gew, estimate="mm_differences", by=~task)

plot(rob1)
rm(rob1)

############################################
## Conjoint Analysis:                     ##
## Assumption 2: No Profile-Order Effects ##
############################################

# Differences in Marginal Means by Profiles
d.cc$profile <- as.factor(d.cc$profile)
rob2 <- cj(data = d.cc, formula=select ~ agenda + duration + scheduling + journey 
           + amenities + accompaniment + atmosphere, id=~ID, weights=~gew, estimate="mm_differences", by=~profile)

plot(rob2)
rm(rob2)

#############################################
## Conjoint Analysis:                      ##
## Assumption 3: Randomization of Profiles ##
#############################################

# Frequencies
wtd <- svydesign(ids=~1, data=d.cc, weights=~gew)
rob3 <- data.frame(prop.table(svytable(~d.cc[,6], design=wtd))*100)
names(rob3) <- c("level", "fre")
for(i in 7:12){
  t1 <- data.frame(prop.table(svytable(~d.cc[,i], design=wtd))*100)
  names(t1) <- c("level", "fre")
  rob3 <- rbind(rob3, t1)
  rm(t1)
}

rob3

rm(rob3, i)

##########################################
## Conjoint Analysis:                   ##
## Figure 1: Effects of design features ##
##########################################

## Marginal Means Total:
mmtot <- cj(data=d.cc, formula=select ~ agenda + duration + scheduling + journey 
            + amenities + accompaniment + atmosphere, id=~ID, weights=~gew, estimate="mm")

plot(mmtot)


###############################################
## Conjoint Analysis:                        ##
## Figure 2: Engaged vs. disengaged citizens ##
###############################################

# Ordinal Regression (M4: Full Model)
wtd <- svydesign(ids=~1, data=gl, weights=~gew)
fit.mod4 <- svyolr(partass ~ age + gender + tertiary + efficacy_int + children +
                     interest + attachment + homeownership + relyearres + localnet +
                     meetav + conflav + efficacy_ext + trust + biasrepr, design=wtd)
summary_table(fit.mod4)

# Fitted Values (Recodes: 1=disengaged, 2=engaged)
fitted <- data.frame(ID = fit.mod4$survey.design$variables$ID, 
                     group = fit.mod4$fitted.values[,1])
fitted$group[fitted$group >= 0.5] <- 1
fitted$group[fitted$group < 0.5] <- 2

# Merge 
d.cc <- merge(d.cc, fitted, by="ID", all.x = TRUE)

# Marginal Means by Group
d.cc$group <- as.factor(d.cc$group)
mm <- cj(data=d.cc, formula=select ~ agenda + duration + scheduling + journey 
         + amenities + accompaniment + atmosphere, id=~ID, weights=~gew, estimate="mm",
         by=~group)

plot(mm[mm$group==1,])
plot(mm[mm$group==2,])


######################################################################################
## Table Appendix: Distinctive features of the "disengaged" and "engaged" citizens  ##
######################################################################################

gl2 <- merge(gl, fitted, by = "ID")
gl2 <- gl2[gl2$ID %in% d.cc$ID,]

wtd<-svydesign(ids=~1, data=gl2, weights=~gew)
round(prop.table(svytable(~tertiary + group, design=wtd), 2)*100, 1)
round(svyby(~efficacy_int, by=~group, design=wtd, FUN=svymean, vartype="ci", na.rm=T), 1)
round(prop.table(svytable(~children + group, design=wtd), 2)*100, 1)
round(prop.table(svytable(~interest + group, design=wtd), 2)*100, 1)
round(svyby(~attachment, by=~group, design=wtd, FUN=svymean, vartype="ci", na.rm=T), 1)
round(prop.table(svytable(~homeownership + group, design=wtd), 2)*100, 1)
round(svyby(~relyearres, by=~group, design=wtd, FUN=svymean, vartype="ci", na.rm=T), 1)
round(svyby(~localnet, by=~group, design=wtd, FUN=svymean, vartype="ci", na.rm=T), 1)
round(svyby(~meetav, by=~group, design=wtd, FUN=svymean, vartype="ci", na.rm=T), 1)
round(svyby(~conflav, by=~group, design=wtd, FUN=svymean, vartype="ci", na.rm=T), 1)
round(svyby(~efficacy_ext, by=~group, design=wtd, FUN=svymean, vartype="ci", na.rm=T), 1)
round(svyby(~trust, by=~group, design=wtd, FUN=svymean, vartype="ci", na.rm=T), 1)
round(svyby(~biasrepr, by=~group, design=wtd, FUN=svymean, vartype="ci", na.rm=T), 1)
svyby(~age, by=~group, design=wtd, svyquantile, quantiles=0.5, na.rm=TRUE)
round(prop.table(svytable(~gender + group, design=wtd), 2)*100, 1)
table(gl2$group)



